#! /usr/bin/env python
"""Print background filename

Print the filename of the current or previous background image.

This file is a part of XSetBg.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2004-2014 PhiloSoft Design"
__license__ = "GNU GPL"


import sys, os
from xsetbg_conf import xsetbg_conf
from xsetbg_db import xsetbg_db


def usage(code=0):
   sys.stderr.write("Usage: %s [-o|--old]\n" % sys.argv[0])
   sys.exit(code)


def get_args():
   from getopt import getopt, GetoptError

   try:
      options, arguments = getopt(sys.argv[1:], "he:o",
                                  ["help", "output-encoding=", "old"])
   except GetoptError:
      usage(1)

   old = False
   output_encoding = None

   for option, value in options:
      if option in ("-h", "--help"):
         usage()
      elif option in ("-e", "--output-encoding"):
         output_encoding = value
      elif option in ("-o", "--old"):
         old = True
      else:
         usage(2)

   if arguments:
      usage(3)

   if output_encoding is None:
      from m_lib.defenc import default_encoding
      output_encoding = default_encoding
   return old, output_encoding

old, output_encoding = get_args()


filename_key = "filename"
old_filename_key = "old_filename"

if old:
   key = old_filename_key
else:
   key = filename_key

filename = xsetbg_db[key]
xsetbg_db.close()

fs_encoding = xsetbg_conf.get("images", "fs_encoding")
filename = unicode(filename, fs_encoding)

print filename.encode(output_encoding)
